# Scripts

This directory contains a series of script that are mostly examples
or manual tests related to PIRT. The scripts are prefixed:
    
* "diffuse_" for code related to diffusion (smoothing).
* "interp_" for code related to purely interpolation.
* "deform_" for code related to deformation.
* "reg_" for code related to registration.
